#    Copyright (c) 2013 Mirantis, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import functions
from yaql.language import parser, context

__versioninfo__ = (0, 3, 0)
__version__ = '.'.join(map(str, __versioninfo__))


def parse(expression):
    return parser.parse(expression)


def create_context(register_functions=True):
    cont = context.Context()
    if register_functions:
        functions.register(cont)
    return context.Context(cont)
